@@ -107,6 +107,9 @@ Glyph2;
  * @CHAFA_SYMBOL_TAG_WIDE: Characters that are two cells wide.
  * @CHAFA_SYMBOL_TAG_AMBIGUOUS: Characters of uncertain width. Always excluded unless specifically asked for.
  * @CHAFA_SYMBOL_TAG_UGLY: Characters that are generally undesired or unlikely to render well. Always excluded unless specifically asked for.
+ * @CHAFA_SYMBOL_TAG_LEGACY: Legacy computer symbols, including sextants, wedges and more.
+ * @CHAFA_SYMBOL_TAG_SEXTANT: Sextant 2x3 mosaics.
+ * @CHAFA_SYMBOL_TAG_WEDGE: Wedge shapes that align with sextants.
  * @CHAFA_SYMBOL_TAG_EXTRA: Symbols not in any other category.
  * @CHAFA_SYMBOL_TAG_BAD: Joint set of ugly and ambiguous characters. Always excluded unless specifically asked for.
  * @CHAFA_SYMBOL_TAG_ALL: Special value meaning all supported symbols.
@@ -394,8 +397,6 @@ compile_symbols (ChafaSymbolMap *symbol_map, GHashTable *desired_symbols)
     symbol_map->packed_bitmaps = g_new (guint64, symbol_map->n_symbols);
     for (i = 0; i < symbol_map->n_symbols; i++)
         symbol_map->packed_bitmaps [i] = symbol_map->symbols [i].bitmap;
-
-    symbol_map->need_rebuild = FALSE;
 }
 
 static void
@@ -442,14 +443,13 @@ compile_symbols_wide (ChafaSymbolMap *symbol_map, GHashTable *desired_symbols)
         symbol_map->packed_bitmaps2 [i * 2] = symbol_map->symbols2 [i].sym [0].bitmap;
         symbol_map->packed_bitmaps2 [i * 2 + 1] = symbol_map->symbols2 [i].sym [1].bitmap;
     }
-
-    symbol_map->need_rebuild = FALSE;
 }
 
 static gboolean
 char_is_selected (GArray *selectors, ChafaSymbolTags tags, gunichar c)
 {
     ChafaSymbolTags auto_exclude_tags = CHAFA_SYMBOL_TAG_BAD;
+    GUnicodeScript script;
     gboolean is_selected = FALSE;
     gint i;
 
@@ -458,6 +458,23 @@ char_is_selected (GArray *selectors, ChafaSymbolTags tags, gunichar c)
         || c == '\t')
         return FALSE;
 
+    /* We don't support RTL, so RTL characters will break the output.
+     *
+     * Ideally we'd exclude the R and AL bidi classes, but unfortunately we don't
+     * have a convenient API available to us to determine the bidi class of a
+     * character. So we just exclude a few scripts and hope for the best.
+     *
+     * A better implementation could extract directionality from the Unicode DB:
+     *
+     * https://www.unicode.org/reports/tr9/#Bidirectional_Character_Types
+     * https://www.unicode.org/Public/UCD/latest/ucd/extracted/DerivedBidiClass.txt */
+    script = g_unichar_get_script (c);
+    if (script == G_UNICODE_SCRIPT_ARABIC
+        || script == G_UNICODE_SCRIPT_HEBREW
+        || script == G_UNICODE_SCRIPT_THAANA
+        || script == G_UNICODE_SCRIPT_SYRIAC)
+        return FALSE;
+
     for (i = 0; i < (gint) selectors->len; i++)
     {
         const Selector *selector = &g_array_index (selectors, Selector, i);
@@ -526,8 +543,6 @@ rebuild_symbols (ChafaSymbolMap *symbol_map)
     {
         for (i = 0; chafa_symbols [i].c != 0; i++)
         {
-            /* This assumes built-in symbols are always non-wide */
-
             if (char_is_selected (symbol_map->selectors,
                                   chafa_symbols [i].sc,
                                   chafa_symbols [i].c))
@@ -543,6 +558,28 @@ rebuild_symbols (ChafaSymbolMap *symbol_map)
         }
     }
 
+    /* Pick built-in symbols (wide) */
+
+    if (symbol_map->use_builtin_glyphs)
+    {
+        for (i = 0; chafa_symbols2 [i].sym [0].c != 0; i++)
+        {
+            if (char_is_selected (symbol_map->selectors,
+                                  chafa_symbols2 [i].sym [0].sc,
+                                  chafa_symbols2 [i].sym [0].c))
+            {
+                ChafaSymbol2 *sym = g_new (ChafaSymbol2, 1);
+
+                *sym = chafa_symbols2 [i];
+                sym->sym [0].coverage = g_memdup (sym->sym [0].coverage, CHAFA_SYMBOL_N_PIXELS);
+                sym->sym [1].coverage = g_memdup (sym->sym [1].coverage, CHAFA_SYMBOL_N_PIXELS);
+                g_hash_table_replace (desired_syms_wide,
+                                      GUINT_TO_POINTER (chafa_symbols2 [i].sym [0].c),
+                                      sym);
+            }
+        }
+    }
+
     /* Pick user glyph symbols */
 
     g_hash_table_iter_init (&iter, symbol_map->glyphs);
@@ -561,7 +598,7 @@ rebuild_symbols (ChafaSymbolMap *symbol_map)
             sym->coverage = (gchar *) bitmap_to_bytes (glyph->bitmap);
             sym->popcount = chafa_population_count_u64 (glyph->bitmap);
             sym->fg_weight = sym->popcount;
-            sym->bg_weight = 64 - sym->popcount;
+            sym->bg_weight = CHAFA_SYMBOL_N_PIXELS - sym->popcount;
 
             g_hash_table_replace (desired_syms, GUINT_TO_POINTER (glyph->c), sym);
         }
@@ -588,7 +625,7 @@ rebuild_symbols (ChafaSymbolMap *symbol_map)
             sym->sym [0].coverage = (gchar *) bitmap_to_bytes (glyph->bitmap [0]);
             sym->sym [0].popcount = chafa_population_count_u64 (glyph->bitmap [0]);
             sym->sym [0].fg_weight = sym->sym [0].popcount;
-            sym->sym [0].bg_weight = 64 - sym->sym [0].popcount;
+            sym->sym [0].bg_weight = CHAFA_SYMBOL_N_PIXELS - sym->sym [0].popcount;
 
             sym->sym [1].sc = tags;
             sym->sym [1].c = glyph->c;
@@ -596,7 +633,7 @@ rebuild_symbols (ChafaSymbolMap *symbol_map)
             sym->sym [1].coverage = (gchar *) bitmap_to_bytes (glyph->bitmap [1]);
             sym->sym [1].popcount = chafa_population_count_u64 (glyph->bitmap [1]);
             sym->sym [1].fg_weight = sym->sym [1].popcount;
-            sym->sym [1].bg_weight = 64 - sym->sym [1].popcount;
+            sym->sym [1].bg_weight = CHAFA_SYMBOL_N_PIXELS - sym->sym [1].popcount;
 
             g_hash_table_replace (desired_syms_wide, GUINT_TO_POINTER (glyph->c), sym);
         }
@@ -604,6 +641,8 @@ rebuild_symbols (ChafaSymbolMap *symbol_map)
 
     compile_symbols_wide (symbol_map, desired_syms_wide);
     g_hash_table_destroy (desired_syms_wide);
+
+    symbol_map->need_rebuild = FALSE;
 }
 
 static GHashTable *
@@ -781,6 +820,8 @@ parse_symbol_tag (const gchar *name, gint len, SelectorType *sel_type_out,
         { "vhalf", CHAFA_SYMBOL_TAG_VHALF },
         { "inverted", CHAFA_SYMBOL_TAG_INVERTED },
         { "braille", CHAFA_SYMBOL_TAG_BRAILLE },
+        { "sextant", CHAFA_SYMBOL_TAG_SEXTANT },
+        { "wedge", CHAFA_SYMBOL_TAG_WEDGE },
         { "technical", CHAFA_SYMBOL_TAG_TECHNICAL },
         { "geometric", CHAFA_SYMBOL_TAG_GEOMETRIC },
         { "ascii", CHAFA_SYMBOL_TAG_ASCII },
@@ -793,6 +834,7 @@ parse_symbol_tag (const gchar *name, gint len, SelectorType *sel_type_out,
         { "extra", CHAFA_SYMBOL_TAG_EXTRA },
         { "alnum", CHAFA_SYMBOL_TAG_ALNUM },
         { "bad", CHAFA_SYMBOL_TAG_BAD },
+        { "legacy", CHAFA_SYMBOL_TAG_LEGACY },
 
         { NULL, 0 }
     };
