@@ -164,6 +164,24 @@ static const SeqStr *color_fbterm_list [] =
     NULL
 };
 
+static const SeqStr kitty_seqs [] =
+{
+    { CHAFA_TERM_SEQ_BEGIN_KITTY_IMMEDIATE_IMAGE_V1, "\033_Ga=T,f=%1,s=%2,v=%3,c=%4,r=%5,m=1\033\\" },
+    { CHAFA_TERM_SEQ_END_KITTY_IMAGE, "\033_Gm=0\033\\" },
+    { CHAFA_TERM_SEQ_BEGIN_KITTY_IMAGE_CHUNK, "\033_Gm=1;" },
+    { CHAFA_TERM_SEQ_END_KITTY_IMAGE_CHUNK, "\033\\" },
+
+    { CHAFA_TERM_SEQ_MAX, NULL }
+};
+
+static const SeqStr iterm2_seqs [] =
+{
+    { CHAFA_TERM_SEQ_BEGIN_ITERM2_IMAGE, "\033]1337;File=inline=1;width=%1;height=%2;preserveAspectRatio=0:" },
+    { CHAFA_TERM_SEQ_END_ITERM2_IMAGE, "\a" },
+
+    { CHAFA_TERM_SEQ_MAX, NULL }
+};
+
 static const SeqStr *fallback_list [] =
 {
     vt220_seqs,
@@ -171,6 +189,8 @@ static const SeqStr *fallback_list [] =
     color_256_seqs,
     color_16_seqs,
     sixel_seqs,
+    kitty_seqs,
+    iterm2_seqs,
     NULL
 };
 
@@ -208,7 +228,10 @@ detect_capabilities (ChafaTermInfo *ti, gchar **envp)
     const gchar *term;
     const gchar *colorterm;
     const gchar *vte_version;
+    const gchar *term_program;
     const gchar *tmux;
+    const gchar *ctx_backend;
+    const gchar *lc_terminal;
     const SeqStr **color_seq_list = color_256_list;
     const SeqStr *gfx_seqs = NULL;
     const SeqStr *rep_seqs_local = NULL;
@@ -224,9 +247,18 @@ detect_capabilities (ChafaTermInfo *ti, gchar **envp)
     vte_version = g_environ_getenv (envp, "VTE_VERSION");
     if (!vte_version) vte_version = "";
 
+    term_program = g_environ_getenv (envp, "TERM_PROGRAM");
+    if (!term_program) term_program = "";
+
     tmux = g_environ_getenv (envp, "TMUX");
     if (!tmux) tmux = "";
 
+    ctx_backend = g_environ_getenv (envp, "CTX_BACKEND");
+    if (!ctx_backend) ctx_backend = "";
+
+    lc_terminal = g_environ_getenv (envp, "LC_TERMINAL");
+    if (!lc_terminal) lc_terminal = "";
+
     /* Some terminals set COLORTERM=truecolor. However, this env var can
      * make its way into environments where truecolor is not desired
      * (e.g. screen sessions), so check it early on and override it later. */
@@ -247,13 +279,38 @@ detect_capabilities (ChafaTermInfo *ti, gchar **envp)
             rep_seqs_local = rep_seqs;
     }
 
+    /* The ctx terminal (https://ctx.graphics/) understands REP */
+    if (strlen (ctx_backend) > 0)
+        rep_seqs_local = rep_seqs;
+
     /* Terminals that advertise 256 colors usually support truecolor too,
      * (VTE, xterm) although some (xterm) may quantize to an indexed palette
      * regardless. */
     if (!strcmp (term, "xterm-256color")
-        || !strcmp (term, "xterm-kitty"))
+        || !strcmp (term, "xterm-direct")
+        || !strcmp (term, "xterm-direct2")
+        || !strcmp (term, "xterm-direct16")
+        || !strcmp (term, "xterm-direct256")
+        || !strcmp (term, "xterm-kitty")
+        || !strcmp (term, "st-256color"))
         color_seq_list = color_direct_list;
 
+    /* Kitty has a unique graphics protocol */
+    if (!strcmp (term, "xterm-kitty"))
+        gfx_seqs = kitty_seqs;
+
+    /* iTerm2 supports truecolor and has a unique graphics protocol */
+    if (!strcasecmp (lc_terminal, "iTerm2")
+        || !strcasecmp (term_program, "iTerm.app"))
+    {
+        color_seq_list = color_direct_list;
+        gfx_seqs = iterm2_seqs;
+    }
+
+    /* Apple Terminal sets TERM=xterm-256color, and does not support truecolor */
+    if (!g_ascii_strcasecmp (term_program, "Apple_Terminal"))
+        color_seq_list = color_256_list;
+
     /* mlterm's truecolor support seems to be broken; it looks like a color
      * allocation issue. This affects character cells, but not sixels.
      *
@@ -269,6 +326,9 @@ detect_capabilities (ChafaTermInfo *ti, gchar **envp)
         gfx_seqs = sixel_seqs;
     }
 
+    if (!strcmp(term, "foot") || !strcmp(term, "foot-direct"))
+        gfx_seqs = sixel_seqs;
+
     /* rxvt 256-color really is 256 colors only */
     if (!strcmp (term, "rxvt-unicode-256color"))
         color_seq_list = color_256_list;
