@@ -83,6 +83,12 @@
  * @CHAFA_TERM_SEQ_BEGIN_SIXELS: Begin sixel image data.
  * @CHAFA_TERM_SEQ_END_SIXELS: End sixel image data.
  * @CHAFA_TERM_SEQ_REPEAT_CHAR: Repeat previous character N times.
+ * @CHAFA_TERM_SEQ_BEGIN_KITTY_IMMEDIATE_IMAGE_V1: Begin upload of Kitty image for immediate display at cursor.
+ * @CHAFA_TERM_SEQ_END_KITTY_IMAGE: End of Kitty image upload.
+ * @CHAFA_TERM_SEQ_BEGIN_KITTY_IMAGE_CHUNK: Begin Kitty image data chunk.
+ * @CHAFA_TERM_SEQ_END_KITTY_IMAGE_CHUNK: End Kitty image data chunk.
+ * @CHAFA_TERM_SEQ_BEGIN_ITERM2_IMAGE: Begin iTerm2 image data.
+ * @CHAFA_TERM_SEQ_END_ITERM2_IMAGE: End of iTerm2 image data.
  * @CHAFA_TERM_SEQ_MAX: Last control sequence plus one.
  *
  * An enumeration of the control sequences supported by #ChafaTermInfo.
@@ -250,7 +256,7 @@ out:
             copy_bytes (out, &seq_str [ofs], seq_args [i].pre_len);     \
             out += seq_args [i].pre_len;                                \
             ofs += seq_args [i].pre_len;                                \
-            out = chafa_format_dec_uint_0_to_9999 (out, args [seq_args [i].arg_index]); \
+            out = intformatter (out, args [seq_args [i].arg_index]); \
         }                                                               \
                                                                         \
         copy_bytes (out, &seq_str [ofs], seq_args [i].pre_len);         \
@@ -302,7 +308,7 @@ emit_seq_2_args_uint8 (const ChafaTermInfo *term_info, gchar *out, ChafaTermSeq
 }
 
 static gchar *
-emit_seq_3_args_uint (const ChafaTermInfo *term_info, gchar *out, ChafaTermSeq seq, guint8 arg0, guint8 arg1, guint8 arg2)
+emit_seq_3_args_uint (const ChafaTermInfo *term_info, gchar *out, ChafaTermSeq seq, guint arg0, guint arg1, guint arg2)
 {
     guint args [3];
 
@@ -312,6 +318,19 @@ emit_seq_3_args_uint (const ChafaTermInfo *term_info, gchar *out, ChafaTermSeq s
     return emit_seq_guint (term_info, out, seq, args, 3);
 }
 
+static gchar *
+emit_seq_5_args_uint (const ChafaTermInfo *term_info, gchar *out, ChafaTermSeq seq, guint arg0, guint arg1, guint arg2, guint arg3, guint arg4)
+{
+    guint args [5];
+
+    args [0] = arg0;
+    args [1] = arg1;
+    args [2] = arg2;
+    args [3] = arg3;
+    args [4] = arg4;
+    return emit_seq_guint (term_info, out, seq, args, 5);
+}
+
 static gchar *
 emit_seq_3_args_uint8 (const ChafaTermInfo *term_info, gchar *out, ChafaTermSeq seq, guint8 arg0, guint8 arg1, guint8 arg2)
 {
@@ -517,7 +536,7 @@ gboolean
 chafa_term_info_set_seq (ChafaTermInfo *term_info, ChafaTermSeq seq, const gchar *str,
                          GError **error)
 {
-    gchar seq_str [CHAFA_TERM_SEQ_MAX];
+    gchar seq_str [CHAFA_TERM_SEQ_LENGTH_MAX];
     SeqArgInfo seq_args [CHAFA_TERM_SEQ_ARGS_MAX];
     gboolean result = FALSE;
 
@@ -544,7 +563,7 @@ chafa_term_info_set_seq (ChafaTermInfo *term_info, ChafaTermSeq seq, const gchar
         if (result == TRUE)
         {
             memcpy (&term_info->seq_str [seq] [0], &seq_str [0],
-                    CHAFA_TERM_SEQ_MAX);
+                    CHAFA_TERM_SEQ_LENGTH_MAX);
             memcpy (&term_info->seq_args [seq] [0], &seq_args [0],
                     CHAFA_TERM_SEQ_ARGS_MAX * sizeof (SeqArgInfo));
 
@@ -580,7 +599,7 @@ chafa_term_info_supplement (ChafaTermInfo *term_info, ChafaTermInfo *source)
         {
             term_info->unparsed_str [i] = g_strdup (source->unparsed_str [i]);
             memcpy (&term_info->seq_str [i] [0], &source->seq_str [i] [0],
-                    CHAFA_TERM_SEQ_MAX);
+                    CHAFA_TERM_SEQ_LENGTH_MAX);
             memcpy (&term_info->seq_args [i] [0], &source->seq_args [i] [0],
                     CHAFA_TERM_SEQ_ARGS_MAX * sizeof (SeqArgInfo));
         }
@@ -627,6 +646,10 @@ gchar *chafa_term_info_emit_##func_name(const ChafaTermInfo *term_info, gchar *d
 gchar *chafa_term_info_emit_##func_name(const ChafaTermInfo *term_info, gchar *dest, guint arg0, guint arg1, guint arg2) \
 { return emit_seq_3_args_uint (term_info, dest, CHAFA_TERM_SEQ_##seq_name, arg0, arg1, arg2); }
 
+#define DEFINE_EMIT_SEQ_5_none_guint(func_name, seq_name) \
+gchar *chafa_term_info_emit_##func_name(const ChafaTermInfo *term_info, gchar *dest, guint arg0, guint arg1, guint arg2, guint arg3, guint arg4) \
+{ return emit_seq_5_args_uint (term_info, dest, CHAFA_TERM_SEQ_##seq_name, arg0, arg1, arg2, arg3, arg4); }
+
 #define DEFINE_EMIT_SEQ_3_none_guint8(func_name, seq_name) \
 gchar *chafa_term_info_emit_##func_name(const ChafaTermInfo *term_info, gchar *dest, guint8 arg0, guint8 arg1, guint8 arg2) \
 { return emit_seq_3_args_uint8 (term_info, dest, CHAFA_TERM_SEQ_##seq_name, arg0, arg1, arg2); }
