@@ -52,7 +52,7 @@ threshold_alpha (ChafaColor col, gint alpha_threshold)
     return col;
 }
 
-static gchar *
+G_GNUC_WARN_UNUSED_RESULT static gchar *
 flush_chars (PrintCtx *ctx, gchar *out)
 {
     gchar buf [8];
@@ -90,7 +90,7 @@ flush_chars (PrintCtx *ctx, gchar *out)
     return out;
 }
 
-static gchar *
+G_GNUC_WARN_UNUSED_RESULT static gchar *
 queue_char (PrintCtx *ctx, gchar *out, gunichar c)
 {
     if (ctx->cur_char == c)
@@ -109,7 +109,7 @@ queue_char (PrintCtx *ctx, gchar *out, gunichar c)
     return out;
 }
 
-static gchar *
+G_GNUC_WARN_UNUSED_RESULT static gchar *
 reset_attributes (PrintCtx *ctx, gchar *out)
 {
     out = chafa_term_info_emit_reset_attributes (ctx->term_info, out);
@@ -123,15 +123,16 @@ reset_attributes (PrintCtx *ctx, gchar *out)
     return out;
 }
 
-static gchar *
+G_GNUC_WARN_UNUSED_RESULT static gchar *
 emit_attributes_truecolor (PrintCtx *ctx, gchar *out,
                            ChafaColor fg, ChafaColor bg, gboolean inverted)
 {
     if (ctx->canvas->config.optimizations & CHAFA_OPTIMIZATION_REUSE_ATTRIBUTES)
     {
-        if ((ctx->cur_inverted && !inverted)
-            || (ctx->cur_fg_direct.ch [3] != 0 && fg.ch [3] == 0)
-            || (ctx->cur_bg_direct.ch [3] != 0 && bg.ch [3] == 0))
+        if (!ctx->canvas->config.fg_only_enabled
+            && ((ctx->cur_inverted && !inverted)
+                || (ctx->cur_fg_direct.ch [3] != 0 && fg.ch [3] == 0)
+                || (ctx->cur_bg_direct.ch [3] != 0 && bg.ch [3] == 0)))
         {
             out = flush_chars (ctx, out);
             out = reset_attributes (ctx, out);
@@ -200,7 +201,7 @@ emit_attributes_truecolor (PrintCtx *ctx, gchar *out,
     return out;
 }
 
-static gchar *
+G_GNUC_WARN_UNUSED_RESULT static gchar *
 emit_ansi_truecolor (PrintCtx *ctx, gchar *out, gint i, gint i_max)
 {
     for ( ; i < i_max; i++)
@@ -237,25 +238,37 @@ emit_ansi_truecolor (PrintCtx *ctx, gchar *out, gint i, gint i_max)
     return out;
 }
 
-static gchar *
+G_GNUC_WARN_UNUSED_RESULT static gchar *
+handle_inverted_with_reuse (PrintCtx *ctx, gchar *out,
+                            guint32 fg, guint32 bg, gboolean inverted)
+{
+    /* We must check fg_only_enabled because we can run into the situation where
+     * fg is set to transparent. */
+    if (!ctx->canvas->config.fg_only_enabled
+        && ((ctx->cur_inverted && !inverted)
+            || (ctx->cur_fg != CHAFA_PALETTE_INDEX_TRANSPARENT && fg == CHAFA_PALETTE_INDEX_TRANSPARENT)
+            || (ctx->cur_bg != CHAFA_PALETTE_INDEX_TRANSPARENT && bg == CHAFA_PALETTE_INDEX_TRANSPARENT)))
+    {
+        out = flush_chars (ctx, out);
+        out = reset_attributes (ctx, out);
+    }
+
+    if (!ctx->cur_inverted && inverted)
+    {
+        out = flush_chars (ctx, out);
+        out = chafa_term_info_emit_invert_colors (ctx->term_info, out);
+    }
+
+    return out;
+}
+
+G_GNUC_WARN_UNUSED_RESULT static gchar *
 emit_attributes_256 (PrintCtx *ctx, gchar *out,
                      guint32 fg, guint32 bg, gboolean inverted)
 {
     if (ctx->canvas->config.optimizations & CHAFA_OPTIMIZATION_REUSE_ATTRIBUTES)
     {
-        if ((ctx->cur_inverted && !inverted)
-            || (ctx->cur_fg != CHAFA_PALETTE_INDEX_TRANSPARENT && fg == CHAFA_PALETTE_INDEX_TRANSPARENT)
-            || (ctx->cur_bg != CHAFA_PALETTE_INDEX_TRANSPARENT && bg == CHAFA_PALETTE_INDEX_TRANSPARENT))
-        {
-            out = flush_chars (ctx, out);
-            out = reset_attributes (ctx, out);
-        }
-
-        if (!ctx->cur_inverted && inverted)
-        {
-            out = flush_chars (ctx, out);
-            out = chafa_term_info_emit_invert_colors (ctx->term_info, out);
-        }
+        out = handle_inverted_with_reuse (ctx, out, fg, bg, inverted);
 
         if (fg != ctx->cur_fg)
         {
@@ -306,7 +319,7 @@ emit_attributes_256 (PrintCtx *ctx, gchar *out,
     return out;
 }
 
-static gchar *
+G_GNUC_WARN_UNUSED_RESULT static gchar *
 emit_ansi_256 (PrintCtx *ctx, gchar *out, gint i, gint i_max)
 {
     for ( ; i < i_max; i++)
@@ -341,25 +354,13 @@ emit_ansi_256 (PrintCtx *ctx, gchar *out, gint i, gint i_max)
     return out;
 }
 
-static gchar *
+G_GNUC_WARN_UNUSED_RESULT static gchar *
 emit_attributes_16 (PrintCtx *ctx, gchar *out,
                     guint32 fg, guint32 bg, gboolean inverted)
 {
     if (ctx->canvas->config.optimizations & CHAFA_OPTIMIZATION_REUSE_ATTRIBUTES)
     {
-        if ((ctx->cur_inverted && !inverted)
-            || (ctx->cur_fg != CHAFA_PALETTE_INDEX_TRANSPARENT && fg == CHAFA_PALETTE_INDEX_TRANSPARENT)
-            || (ctx->cur_bg != CHAFA_PALETTE_INDEX_TRANSPARENT && bg == CHAFA_PALETTE_INDEX_TRANSPARENT))
-        {
-            out = flush_chars (ctx, out);
-            out = reset_attributes (ctx, out);
-        }
-
-        if (!ctx->cur_inverted && inverted)
-        {
-            out = flush_chars (ctx, out);
-            out = chafa_term_info_emit_invert_colors (ctx->term_info, out);
-        }
+        out = handle_inverted_with_reuse (ctx, out, fg, bg, inverted);
 
         if (fg != ctx->cur_fg)
         {
@@ -411,7 +412,7 @@ emit_attributes_16 (PrintCtx *ctx, gchar *out,
 }
 
 /* Uses aixterm control codes for bright colors */
-static gchar *
+G_GNUC_WARN_UNUSED_RESULT static gchar *
 emit_ansi_16 (PrintCtx *ctx, gchar *out, gint i, gint i_max)
 {
     for ( ; i < i_max; i++)
@@ -446,7 +447,7 @@ emit_ansi_16 (PrintCtx *ctx, gchar *out, gint i, gint i_max)
     return out;
 }
 
-static gchar *
+G_GNUC_WARN_UNUSED_RESULT static gchar *
 emit_ansi_fgbg_bgfg (PrintCtx *ctx, gchar *out, gint i, gint i_max)
 {
     gunichar blank_symbol = 0;
@@ -514,7 +515,7 @@ emit_ansi_fgbg_bgfg (PrintCtx *ctx, gchar *out, gint i, gint i_max)
     return out;
 }
 
-static gchar *
+G_GNUC_WARN_UNUSED_RESULT static gchar *
 emit_ansi_fgbg (PrintCtx *ctx, gchar *out, gint i, gint i_max)
 {
     for ( ; i < i_max; i++)
@@ -571,9 +572,14 @@ build_ansi_gstring (ChafaCanvas *canvas, ChafaTermInfo *ti)
         prealloc_string (gs, i_step);
         out = gs->str + gs->len;
 
-        /* Avoid control codes in FGBG mode */
-        if (i == 0 && canvas->config.canvas_mode != CHAFA_CANVAS_MODE_FGBG)
+        /* Avoid control codes in FGBG mode. Don't reset attributes when BG
+         * is held, to preserve any BG color set previously. */
+        if (i == 0
+            && canvas->config.canvas_mode != CHAFA_CANVAS_MODE_FGBG
+            && !canvas->config.fg_only_enabled)
+        {
             out = reset_attributes (&ctx, out);
+        }
 
         switch (canvas->config.canvas_mode)
         {
@@ -587,6 +593,9 @@ build_ansi_gstring (ChafaCanvas *canvas, ChafaTermInfo *ti)
             case CHAFA_CANVAS_MODE_INDEXED_16:
                 out = emit_ansi_16 (&ctx, out, i, i_next);
                 break;
+            case CHAFA_CANVAS_MODE_INDEXED_8:
+                out = emit_ansi_16 (&ctx, out, i, i_next);
+                break;
             case CHAFA_CANVAS_MODE_FGBG_BGFG:
                 out = emit_ansi_fgbg_bgfg (&ctx, out, i, i_next);
                 break;
@@ -600,9 +609,13 @@ build_ansi_gstring (ChafaCanvas *canvas, ChafaTermInfo *ti)
 
         out = flush_chars (&ctx, out);
 
-        /* Avoid control codes in FGBG mode */
-        if (canvas->config.canvas_mode != CHAFA_CANVAS_MODE_FGBG)
+        /* Avoid control codes in FGBG mode. Don't reset attributes when BG
+         * is held, to preserve any BG color set previously. */
+        if (canvas->config.canvas_mode != CHAFA_CANVAS_MODE_FGBG
+            && !canvas->config.fg_only_enabled)
+        {
             out = reset_attributes (&ctx, out);
+        }
 
         /* Last line should not end in newline */
         if (i_next < i_max)
