@@ -25,6 +25,8 @@
 #include "internal/chafa-color-hash.h"
 #include "internal/chafa-dither.h"
 #include "internal/chafa-indexed-image.h"
+#include "internal/chafa-iterm2-canvas.h"
+#include "internal/chafa-kitty-canvas.h"
 #include "internal/chafa-palette.h"
 #include "internal/chafa-sixel-canvas.h"
 
@@ -109,6 +111,7 @@ struct ChafaCanvasConfig
     ChafaSymbolMap symbol_map;
     ChafaSymbolMap fill_symbol_map;
     guint preprocessing_enabled : 1;
+    guint fg_only_enabled : 1;
     ChafaOptimizations optimizations;
 };
 
@@ -119,6 +122,7 @@ typedef struct ChafaCanvasCell ChafaCanvasCell;
 /* Library functions */
 
 extern ChafaSymbol *chafa_symbols;
+extern ChafaSymbol2 *chafa_symbols2;
 
 void chafa_init_palette (void);
 void chafa_init_symbols (void);
@@ -165,7 +169,9 @@ gint *chafa_gen_bayer_matrix (gint matrix_size, gdouble magnitude);
 
 #ifdef HAVE_MMX_INTRINSICS
 void calc_colors_mmx (const ChafaPixel *pixels, ChafaColorAccum *accums_out, const guint8 *cov);
-void leave_mmx (void);
+void chafa_leave_mmx (void);
+#else
+# define chafa_leave_mmx()
 #endif
 
 #ifdef HAVE_SSE41_INTRINSICS
