@@ -72,6 +72,7 @@ typedef struct
     gboolean stretch;
     gboolean zoom;
     gboolean watch;
+    gboolean fg_only;
     gint width, height;
     gint cell_width, cell_height;
     gdouble font_ratio;
@@ -225,10 +226,10 @@ print_summary (void)
 
     "      --bg=COLOR     Background color of display (color name or hex).\n"
     "      --clear        Clear screen before processing each file.\n"
-    "  -c, --colors=MODE  Set output color mode; one of [none, 2, 16, 240, 256,\n"
+    "  -c, --colors=MODE  Set output color mode; one of [none, 2, 8, 16, 240, 256,\n"
     "                     full]. Defaults to full (24-bit).\n"
     "      --color-extractor=EXTR  Method for extracting color from an area\n"
-    "                     [average, median]. Median is the default.\n"
+    "                     [average, median]. Average is the default.\n"
     "      --color-space=CS  Color space used for quantization; one of [rgb, din99d].\n"
     "                     Defaults to rgb, which is faster but less accurate.\n"
     "      --dither=DITHER  Set output dither mode; one of [none, ordered,\n"
@@ -239,15 +240,18 @@ print_summary (void)
     "                     Defaults to 1.0.\n"
     "  -d, --duration=SECONDS  The time to show each file. If showing a single file,\n"
     "                     defaults to zero for a still image and infinite for an\n"
-    "                     animation. For multiple files, defaults to 3.0. Animations\n"
+    "                     animation. For multiple files, defaults to zero. Animations\n"
     "                     will always be played through at least once.\n"
     "      --fg=COLOR     Foreground color of display (color name or hex).\n"
+    "      --fg-only      Leave the background color untouched. This produces\n"
+    "                     character-cell output using foreground colors only.\n"
     "      --fill=SYMS    Specify character symbols to use for fill/gradients.\n"
     "                     Defaults to none. See below for full usage.\n"
     "      --font-ratio=W/H  Target font's width/height ratio. Can be specified as\n"
     "                     a real number or a fraction. Defaults to 1/2.\n"
-    "  -f, --format=FORMAT  Set output format; one of [sixels, symbols]. Sixels\n"
-    "                     yield much better quality but are rarely supported.\n"
+    "  -f, --format=FORMAT  Set output format; one of [iterm, kitty, sixels, symbols].\n"
+    "                     Iterm, kitty and sixels yield much higher quality but enjoy\n"
+    "                     limited support. Symbols mode yields beautiful ANSI art.\n"
     "      --glyph-file=FILE  Load glyph information from FILE, which can be any\n"
     "                     font file supported by FreeType (TTF, PCF, etc).\n"
     "      --invert       Invert video. For display with bright backgrounds in\n"
@@ -279,13 +283,14 @@ print_summary (void)
 
     "  Accepted classes for --symbols and --fill are [all, none, space, solid,\n"
     "  stipple, block, border, diagonal, dot, quad, half, hhalf, vhalf, inverted,\n"
-    "  braille, technical, geometric, ascii, extra]. Some symbols belong to multiple\n"
-    "  classes, e.g. diagonals are also borders. You can specify a list of classes\n"
-    "  separated by commas, or prefix them with + and - to add or remove symbols\n"
-    "  relative to the existing set. The ordering is significant.\n\n"
+    "  braille, technical, geometric, ascii, legacy, sextant, wedge, wide, narrow,\n"
+    "  extra]. Some symbols belong to multiple classes, e.g. diagonals are also\n"
+    "  borders. You can specify a list of classes separated by commas, or prefix them\n"
+    "  with + and - to add or remove symbols relative to the existing set. The\n"
+    "  ordering is significant.\n\n"
 
-    "  The default symbol set is all-stipple-braille-ascii+space-extra-inverted for\n"
-    "  all modes except \"none\", which uses all-stipple-braille-ascii+space-extra.\n\n"
+    "  The default symbol set is block+border+space-wide-inverted for all modes\n"
+    "  except \"none\", which uses block+border+space-wide (including inverse symbols).\n\n"
 
     "Examples:\n"
 
@@ -313,6 +318,8 @@ parse_colors_arg (G_GNUC_UNUSED const gchar *option_name, const gchar *value, G_
         options.mode = CHAFA_CANVAS_MODE_FGBG_BGFG;
     else if (!g_ascii_strcasecmp (value, "16"))
         options.mode = CHAFA_CANVAS_MODE_INDEXED_16;
+    else if (!g_ascii_strcasecmp (value, "8"))
+        options.mode = CHAFA_CANVAS_MODE_INDEXED_8;
     else if (!g_ascii_strcasecmp (value, "240"))
         options.mode = CHAFA_CANVAS_MODE_INDEXED_240;
     else if (!g_ascii_strcasecmp (value, "256"))
@@ -461,10 +468,19 @@ parse_format_arg (G_GNUC_UNUSED const gchar *option_name, const gchar *value, G_
     {
         pixel_mode = CHAFA_PIXEL_MODE_SIXELS;
     }
+    else if (!strcasecmp (value, "kitty"))
+    {
+        pixel_mode = CHAFA_PIXEL_MODE_KITTY;
+    }
+    else if (!strcasecmp (value, "iterm")
+             || !strcasecmp (value, "iterm2"))
+    {
+        pixel_mode = CHAFA_PIXEL_MODE_ITERM2;
+    }
     else
     {
         g_set_error (error, G_OPTION_ERROR, G_OPTION_ERROR_BAD_VALUE,
-                     "Output format given as '%s'. Must be one of [symbols, sixels].",
+                     "Output format given as '%s'. Must be one of [iterm, kitty, sixels, symbols].",
                      value);
         result = FALSE;
     }
@@ -727,8 +743,32 @@ static void
 get_tty_size (void)
 {
     struct winsize w;
+    gboolean have_winsz = FALSE;
 
-    if (ioctl (STDOUT_FILENO, TIOCGWINSZ, &w) < 0)
+    if (ioctl (STDOUT_FILENO, TIOCGWINSZ, &w) >= 0
+        || ioctl (STDERR_FILENO, TIOCGWINSZ, &w) >= 0
+        || ioctl (STDIN_FILENO, TIOCGWINSZ, &w) >= 0)
+        have_winsz = TRUE;
+
+    if (!have_winsz)
+    {
+        const gchar *term_path;
+        gint fd = -1;
+
+        term_path = ctermid (NULL);
+        if (term_path)
+            fd = open (term_path, O_RDONLY);
+
+        if (fd >= 0)
+        {
+            if (ioctl (fd, TIOCGWINSZ, &w) >= 0)
+                have_winsz = TRUE;
+
+            close (fd);
+        }
+    }
+
+    if (!have_winsz)
         return;
 
     if (w.ws_col > 0)
@@ -807,8 +847,10 @@ detect_terminal (ChafaTermInfo **term_info_out, ChafaCanvasMode *mode_out, Chafa
     else
         mode = CHAFA_CANVAS_MODE_FGBG;
 
-    if (chafa_term_info_have_seq (term_info, CHAFA_TERM_SEQ_BEGIN_SIXELS)
-        && chafa_term_info_have_seq (term_info, CHAFA_TERM_SEQ_END_SIXELS))
+    if (chafa_term_info_have_seq (term_info, CHAFA_TERM_SEQ_BEGIN_KITTY_IMMEDIATE_IMAGE_V1))
+        pixel_mode = CHAFA_PIXEL_MODE_KITTY;
+    else if (chafa_term_info_have_seq (term_info, CHAFA_TERM_SEQ_BEGIN_SIXELS)
+             && chafa_term_info_have_seq (term_info, CHAFA_TERM_SEQ_END_SIXELS))
         pixel_mode = CHAFA_PIXEL_MODE_SIXELS;
     else
         pixel_mode = CHAFA_PIXEL_MODE_SYMBOLS;
@@ -831,6 +873,7 @@ parse_options (int *argc, char **argv [])
 {
     GError *error = NULL;
     GOptionContext *context;
+    gint detected_width;
     gboolean result = TRUE;
     const GOptionEntry option_entries [] =
     {
@@ -849,8 +892,9 @@ parse_options (int *argc, char **argv [])
         { "dither-intensity", '\0',  0, G_OPTION_ARG_DOUBLE,   &options.dither_intensity, "Dither intensity", NULL },
         { "duration",    'd',  0, G_OPTION_ARG_DOUBLE,   &options.file_duration_s, "Duration", NULL },
         { "fg",          '\0', 0, G_OPTION_ARG_CALLBACK, parse_fg_color_arg,    "Foreground color of display", NULL },
+        { "fg-only",     '\0', 0, G_OPTION_ARG_NONE,     &options.fg_only,      "Foreground only", NULL },
         { "fill",        '\0', 0, G_OPTION_ARG_CALLBACK, parse_fill_arg,        "Fill symbols", NULL },
-        { "format",      'f',  0, G_OPTION_ARG_CALLBACK, parse_format_arg,      "Format of output pixel data (ansi or sixels)", NULL },
+        { "format",      'f',  0, G_OPTION_ARG_CALLBACK, parse_format_arg,      "Format of output pixel data (iterm, kitty, sixels or symbols)", NULL },
         { "font-ratio",  '\0', 0, G_OPTION_ARG_CALLBACK, parse_font_ratio_arg,  "Font ratio", NULL },
         { "glyph-file",  '\0', 0, G_OPTION_ARG_CALLBACK, parse_glyph_file_arg,  "Glyph file", NULL },
         { "invert",      '\0', 0, G_OPTION_ARG_NONE,     &options.invert,       "Invert foreground/background", NULL },
@@ -880,12 +924,10 @@ parse_options (int *argc, char **argv [])
     /* Defaults */
 
     options.symbol_map = chafa_symbol_map_new ();
-    chafa_symbol_map_add_by_tags (options.symbol_map, CHAFA_SYMBOL_TAG_ALL);
-    chafa_symbol_map_remove_by_tags (options.symbol_map, CHAFA_SYMBOL_TAG_STIPPLE);
-    chafa_symbol_map_remove_by_tags (options.symbol_map, CHAFA_SYMBOL_TAG_BRAILLE);
-    chafa_symbol_map_remove_by_tags (options.symbol_map, CHAFA_SYMBOL_TAG_ASCII);
-    chafa_symbol_map_remove_by_tags (options.symbol_map, CHAFA_SYMBOL_TAG_EXTRA);
+    chafa_symbol_map_add_by_tags (options.symbol_map, CHAFA_SYMBOL_TAG_BLOCK);
+    chafa_symbol_map_add_by_tags (options.symbol_map, CHAFA_SYMBOL_TAG_BORDER);
     chafa_symbol_map_add_by_tags (options.symbol_map, CHAFA_SYMBOL_TAG_SPACE);
+    chafa_symbol_map_remove_by_tags (options.symbol_map, CHAFA_SYMBOL_TAG_WIDE);
 
     options.fill_symbol_map = chafa_symbol_map_new ();
 
@@ -898,6 +940,7 @@ parse_options (int *argc, char **argv [])
     options.dither_grain_height = -1;  /* Unset */
     options.dither_intensity = 1.0;
     options.preprocess = TRUE;
+    options.fg_only = FALSE;
     options.color_extractor = CHAFA_COLOR_EXTRACTOR_AVERAGE;
     options.color_space = CHAFA_COLOR_SPACE_RGB;
     options.width = 80;
@@ -913,6 +956,8 @@ parse_options (int *argc, char **argv [])
     options.anim_speed_multiplier = 1.0;
     get_tty_size ();
 
+    detected_width = options.width;
+
     if (!g_option_context_parse (context, argc, argv, &error))
     {
         g_printerr ("%s: %s\n", options.executable_name, error->message);
@@ -936,7 +981,7 @@ parse_options (int *argc, char **argv [])
     }
     else
     {
-        /* Sixel defaults */
+        /* iTerm2/Kitty/sixel defaults */
 
         if (options.mode == CHAFA_CANVAS_MODE_MAX)
             options.mode = CHAFA_CANVAS_MODE_TRUECOLOR;
@@ -945,9 +990,25 @@ parse_options (int *argc, char **argv [])
         if (options.dither_grain_height < 0)
             options.dither_grain_height = 1;
         if (options.font_ratio < 0.0)
-            options.font_ratio = 1.0;
+            options.font_ratio = 1.0 / 2.0;
     }
 
+    /* Kitty leaves the cursor in the column trailing the last row of the
+     * image. However, if the image is as wide as the terminal, the cursor
+     * will wrap to the first column of the following row, making us lose
+     * track of its position.
+     *
+     * This is not a problem when instructed to clear the terminal, as we
+     * use absolute positioning then.
+     *
+     * If needed, trim one column from the image to make the cursor position
+     * predictable. */
+    if (options.pixel_mode == CHAFA_PIXEL_MODE_KITTY
+        && !options.clear
+        && options.width > 1
+        && options.width == detected_width)
+        options.width -= 1;
+
     if (options.work_factor < 1 || options.work_factor > 9)
     {
         g_printerr ("%s: Work factor must be in the range [1-9].\n", options.executable_name);
@@ -1111,6 +1172,8 @@ build_string (ChafaPixelType pixel_type, const guint8 *pixels,
     chafa_canvas_config_set_fg_color (config, options.fg_color);
     chafa_canvas_config_set_bg_color (config, options.bg_color);
     chafa_canvas_config_set_preprocessing_enabled (config, options.preprocess);
+    chafa_canvas_config_set_fg_only_enabled (config, options.fg_only);
+
     if (options.transparency_threshold >= 0.0)
         chafa_canvas_config_set_transparency_threshold (config, options.transparency_threshold);
     if (options.cell_width > 0 && options.cell_height > 0)
@@ -1273,6 +1336,12 @@ interruptible_usleep (gint us)
     }
 }
 
+static gboolean
+write_to_stdout (gpointer buf, gsize len)
+{
+   return fwrite (buf, 1, len, stdout) == len ? TRUE : FALSE;
+}
+
 /* FIXME: This function is ripe for refactoring, probably to something with
  * a heap-allocated context. */
 static gboolean
@@ -1463,14 +1532,22 @@ run_magickwand (const gchar *filename, gboolean is_first_file, gboolean is_first
             if (is_first_frame && !options.clear && !is_first_file)
                 *(p0++) = '\n';
 
-            fwrite (buf, sizeof (gchar), p0 - buf, stdout);
-            fwrite (frame->gs->str, sizeof (gchar), frame->gs->len, stdout);
+            if (!write_to_stdout (buf, p0 - buf))
+                goto out;
+            if (!write_to_stdout (frame->gs->str, frame->gs->len))
+                goto out;
 
             /* No linefeed after frame in sixel mode */
-            if (options.pixel_mode == CHAFA_PIXEL_MODE_SYMBOLS)
-                fputc ('\n', stdout);
+            if (options.pixel_mode == CHAFA_PIXEL_MODE_SYMBOLS
+                || options.pixel_mode == CHAFA_PIXEL_MODE_KITTY
+                || options.pixel_mode == CHAFA_PIXEL_MODE_ITERM2)
+            {
+                if (!write_to_stdout ("\n", 1))
+                    goto out;
+            }
 
-            fflush (stdout);
+            if (fflush (stdout) != 0)
+                goto out;
 
             if (is_animation)
             {
@@ -1615,14 +1692,22 @@ run_gif (const gchar *filename, gboolean is_first_file, gboolean is_first_frame,
             if (is_first_frame && !options.clear && !is_first_file)
                 *(p0++) = '\n';
 
-            fwrite (buf, sizeof (gchar), p0 - buf, stdout);
-            fwrite (frame->gs->str, sizeof (gchar), frame->gs->len, stdout);
+            if (!write_to_stdout (buf, p0 - buf))
+                goto out;
+            if (!write_to_stdout (frame->gs->str, frame->gs->len))
+                goto out;
 
             /* No linefeed after frame in sixel mode */
-            if (options.pixel_mode == CHAFA_PIXEL_MODE_SYMBOLS)
-                fputc ('\n', stdout);
+            if (options.pixel_mode == CHAFA_PIXEL_MODE_SYMBOLS
+                || options.pixel_mode == CHAFA_PIXEL_MODE_KITTY
+                || options.pixel_mode == CHAFA_PIXEL_MODE_ITERM2)
+            {
+                if (!write_to_stdout ("\n", 1))
+                    goto out;
+            }
 
-            fflush (stdout);
+            if (fflush (stdout) != 0)
+                goto out;
 
             if (is_animation)
             {
